ConnectedNetworking class

Constructors

ConnectedNetworking()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

connectToWifi({required String ssid, required String password}) Future<bool>
copyToClipboard(String text) Future<bool>
discoverServices({required String serviceType, int timeoutSeconds = 10}) Future<List<NetworkService>>
getConnectedDevices() Future<List<String>>
getCurrentWifiSSID() Future<String?>
getLocalIPAddress() Future<String?>
hasNetworkPermissions() Future<bool>
isHotspotEnabled() Future<bool>
openWifiSettings() Future<bool>
requestNetworkPermissions() Future<bool>
startHotspot({required String ssid, required String password}) Future<bool>
startServiceAdvertising({required String serviceName, required String serviceType, required int port, Map<String, String>? txtRecords}) Future<bool>
stopHotspot() Future<bool>
stopServiceAdvertising() Future<bool>