NetworkService class

Constructors

NetworkService({required String name, required String host, required int port, required Map<String, String> txtRecords})
NetworkService.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
host String
final
name String
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txtRecords Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited